@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use 5.006;
 use strict;
 use warnings;
@@ -11,9 +11,13 @@ use Time::HiRes qw(gettimeofday);
 use Want qw/want/;
 use Digest::SHA;
 
-our $JSON;
+our ($JSON, %PRIVATE);
 BEGIN {
 	$JSON = JSON->new->utf8->canonical(1)->allow_blessed->convert_blessed;
+	%PRIVATE = (
+		map { $_ => 1 } 
+		qw/new run logger logInfo logError raiseError graft pretty serialize DESTROY TO_JSON AUTOLOAD/
+	);
 }
 
 sub new {
@@ -51,7 +55,7 @@ sub run {
 
 	if (! $j->{_application}) {
 		$j->response->raiseError('No application passed to run', 500);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 
 	my $content_type = $j->request->content_type;
@@ -63,7 +67,7 @@ sub run {
 
 	unless ((reftype($j->params) || "") eq 'HASH') {
 		$j->response->raiseError('Invalid parameters', 400);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 
 	$j->sid = $j->request->cookies->{sid};
@@ -82,9 +86,9 @@ sub run {
 	my $session = $j->{_application}->$auth($j, $pkg->new());
 	my $req = $j->params->req;
 	$req =~ /^([a-z][0-9a-zA-Z_]{1,31})$/; $req = $1 // '';
-	if (!$req || !$session) {
+	if (!$req || !$session || $PRIVATE{$req}) {
 		$j->response->raiseError('Invalid request', 400);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 
 	$j->response->authenticated = \1;
@@ -92,7 +96,7 @@ sub run {
 
 	unless ($j->{_application}->can($req)) {
 		$j->response->raiseError('Invalid request', 400);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 
 	my ($login, $logout) = (
@@ -103,7 +107,7 @@ sub run {
 	my $out = eval { $j->{_application}->$req($j) };
 	if ($@) {
 		$j->response->raiseError(['Unclassified Error', $@], 400);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 	$j->session = $out if ( $login || $logout );
 
@@ -111,7 +115,7 @@ sub run {
 
 	if ((!$j->response->authenticated || !$j->session) && !($login || $logout)) {
 		$j->response->raiseError('Unauthenticated during the request', 400);
-		return $j->error_response($j->response);
+		return $j->_response($j->response);
 	}
 
 	my $cookie = {
@@ -121,10 +125,10 @@ sub run {
 		expires => $logout ? time : ((ref $j->session && $j->session->expires) || time + 24 * 60 * 60),
 	};
 
-	return $j->okay_response($j->response, $cookie);
+	return $j->_response($j->response, $cookie);
 }
 
-sub okay_response {
+sub _response {
 	my ($self, $response_body, $cookie, $status) = @_;
 	my $res = $self->request->new_response($response_body->status_code ||= $status ||= 200);
 	$res->cookies->{sid} = $cookie if $cookie;
@@ -133,14 +137,6 @@ sub okay_response {
 	return $res->finalize;
 }
 
-sub error_response {
-	my ($self, $response_body, $status) = @_;
-	my $res = $self->request->new_response($status || $response_body->status_code);
-	$res->content_type('application/json');
-	$res->body($response_body->serialize());
-	return $res->finalize;
-}
-
 sub logger {
 	my ($self, $logger) = @_;
 	$self->{_logger} = $logger if ($logger);
